==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/functions_74.js <==
var searchData=
[
  ['tcl_5fappinit',['Tcl_AppInit',['../stupidtk_8c.html#aed8bfdf158965901338981f54c152954',1,'stupidtk.c']]],
  ['tcl_5fcmd',['tcl_cmd',['../tclAPI_8c.html#a069c1e1f6fb17be5b26f89d96650d1a0',1,'tcl_cmd(Tcl_Interp *interp, const char *cmd):&#160;tclAPI.c'],['../plserver_8c.html#a3c560dacc9c6efe86130a07308659ad5',1,'tcl_cmd(Tcl_Interp *interp, const char *cmd):&#160;plserver.c']]],
  ['tcl_5fgetmatrixptr',['Tcl_GetMatrixPtr',['../tclMatrix_8c.html#af3739ddb6ec61b0a5ca638948d7b55c7',1,'Tcl_GetMatrixPtr(Tcl_Interp *interp, const char *matName):&#160;tclMatrix.c'],['../tclMatrix_8h.html#ab2c44fbfdb9e0b9d4079a377c82dc126',1,'Tcl_GetMatrixPtr(Tcl_Interp *interp, const char *matName):&#160;tclMatrix.c']]],
  ['tcl_5fmatrixcmd',['Tcl_MatrixCmd',['../tclMatrix_8c.html#a03ea7ccdc423c41169df122cadc08b71',1,'Tcl_MatrixCmd(ClientData PL_UNUSED(clientData), Tcl_Interp *interp, int argc, const char **argv):&#160;tclMatrix.c'],['../tclMatrix_8h.html#abf562e3a618ffccdb8f7064fd715ad7b',1,'Tcl_MatrixCmd(ClientData clientData, Tcl_Interp *interp, int argc, const char **argv):&#160;tclMatrix.h']]],
  ['tcl_5fmatrixinstallxtnsn',['Tcl_MatrixInstallXtnsn',['../tclMatrix_8c.html#abea9f1db6809a56f0a3712da6d65eeb7',1,'Tcl_MatrixInstallXtnsn(const char *cmd, tclMatrixXtnsnProc proc):&#160;tclMatrix.c'],['../tclMatrix_8h.html#ad3fb59e9e5e16f94b1d7d0780cd768f2',1,'Tcl_MatrixInstallXtnsn(const char *cmd, tclMatrixXtnsnProc proc):&#160;tclMatrix.c']]],
  ['tcl_5ftransform',['Tcl_transform',['../tclAPI_8c.html#ac10d278b0793f65aa2d27b3ca83aed5c',1,'tclAPI.c']]],
  ['tclgetstartupscriptfilename',['TclGetStartupScriptFileName',['../tclMain_8c.html#a1c7373167ed7e868005ffffca214b24a',1,'tclMain.c']]],
  ['tcllist2py',['TclList2Py',['../namespaceTclSup.html#a9a22072a7a760eb1c275996e03c9ebda',1,'TclSup']]],
  ['tclmatrix_5ffeval',['tclMatrix_feval',['../tclAPI_8c.html#a92aef5e047b1e762bf45ec49531a072a',1,'tclAPI.c']]],
  ['tclsetstartupscriptfilename',['TclSetStartupScriptFileName',['../tclMain_8c.html#ae75c91cb39ac256237bd748315841dde',1,'tclMain.c']]],
  ['testlib_5fbroken_5fdown_5ftime',['testlib_broken_down_time',['../qsastime__testlib_8c.html#a42b776f3b8bba73a0329bafc3d382bbb',1,'qsastime_testlib.c']]],
  ['testlib_5fmjd',['testlib_MJD',['../qsastime__testlib_8c.html#a0a4b5e3359b4f06df6b7746bc9c34840',1,'qsastime_testlib.c']]],
  ['testppchar',['testppchar',['../plplot__octaveOCTAVE__wrap_8cxx.html#a920477bad4bcedede7d93be4a1d1c513',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['text',['text',['../classplstream.html#a3cdd797ab78f23697ba7a349dc0f0e74',1,'plstream::text()'],['../classplplot_1_1core_1_1PLStream.html#aadffc2af4b9889d9586f56d2fc073536',1,'plplot.core.PLStream.text()']]],
  ['text2fci',['text2fci',['../plcore_8c.html#ab5ed11ea9469ea9e4c5e1d8c5fb3e488',1,'plcore.c']]],
  ['text2num',['text2num',['../plcore_8c.html#a005b7ebf9131c9ee0266602f3830f6d5',1,'plcore.c']]],
  ['text_5fbegin_5fcairo',['text_begin_cairo',['../cairo_8c.html#aa230a846e80ae8ace11c65d3b1840eaa',1,'cairo.c']]],
  ['text_5fchar_5fcairo',['text_char_cairo',['../cairo_8c.html#aeafc2e3ee56fe62b57c15db0aa1b5a9d',1,'cairo.c']]],
  ['text_5fend_5fcairo',['text_end_cairo',['../cairo_8c.html#ab189f0a7c0f472269f925a05126f1c5d',1,'cairo.c']]],
  ['text_5fesc_5fcairo',['text_esc_cairo',['../cairo_8c.html#a324842987dca601eb1df6908fc11685a',1,'cairo.c']]],
  ['thindata',['thindata',['../csa_8c.html#a669921b0d6bbc7d4950d4e9782b67b87',1,'csa.c']]],
  ['timefmt',['timefmt',['../classplstream.html#a748813a8db4e3cc186b5d9fae8538c39',1,'plstream::timefmt()'],['../classplplot_1_1core_1_1PLStream.html#a691f55bf90b757df6aaca9fef7d1e20f',1,'plplot.core.PLStream.timefmt()']]],
  ['tkw_5fstorecolor',['Tkw_StoreColor',['../pltkwd_8h.html#aa590122849f626ceae0d0bf2feef9a7f',1,'pltkwd.h']]],
  ['top_5fcont_5fget',['TOP_CONT_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a76b552e9f43e5ddce941de19102d17df',1,'plplot::core::plplotjavacJNI']]],
  ['tr0',['tr0',['../classplstream.html#a2c4b8d115749666eaf55eff4c76926ec',1,'plstream']]],
  ['tr1',['tr1',['../classplstream.html#a42a2e792b9a60193c335aa7e6543b86a',1,'plstream']]],
  ['tr2',['tr2',['../classplstream.html#a8220e4e66a54eb70e152f8b943c0a6eb',1,'plstream']]],
  ['tr2p',['tr2p',['../classplstream.html#afbd3996bfd02a5c4c7f6f1d85405930a',1,'plstream']]],
  ['tran',['tran',['../plfill_8c.html#a96d6559529e7881ab25d69ee516bd366',1,'plfill.c']]],
  ['translate_5fcolorbar_5foption',['translate_colorbar_option',['../plplot__impl_8c.html#aa09a986f70df1a7bdd15c1398c8c51c7',1,'plplot_impl.c']]],
  ['translate_5flegend_5foption',['translate_legend_option',['../plplot__impl_8c.html#a04be7b6c1cd524108031ee605cbb1de2',1,'plplot_impl.c']]],
  ['translate_5fparse_5foption',['translate_parse_option',['../plplot__impl_8c.html#aaf9fa0bd5c22c242354bea364e5018eb',1,'plplot_impl.c']]],
  ['translate_5fposition_5foption',['translate_position_option',['../plplot__impl_8c.html#a860bc00275b3a98b902d801e82315b40',1,'plplot_impl.c']]],
  ['triangle_5faddpoint',['triangle_addpoint',['../csa_8c.html#ad0b5597e62a4eaadfc691161ce0d5833',1,'csa.c']]],
  ['triangle_5fcalculatebc',['triangle_calculatebc',['../csa_8c.html#a69177ee7bf317363bd9b9c78656cb514',1,'csa.c']]],
  ['triangle_5fcreate',['triangle_create',['../csa_8c.html#a37b8b91050fbf95944eadd7ba22d177e',1,'csa.c']]],
  ['triangle_5fdestroy',['triangle_destroy',['../csa_8c.html#a1d77f19bb03c49d46bc43a325c9d8208',1,'csa.c']]],
  ['triangle_5fscale_5fget',['triangle_scale_get',['../nnpi_8c.html#aba9a1e6c098204686a1090f3637fb7c6',1,'nnpi.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/functions_74.js <==
var searchData=
[
  ['tcl_5fappinit',['Tcl_AppInit',['../stupidtk_8c.html#aed8bfdf158965901338981f54c152954',1,'stupidtk.c']]],
  ['tcl_5fcmd',['tcl_cmd',['../tclAPI_8c.html#a069c1e1f6fb17be5b26f89d96650d1a0',1,'tcl_cmd(Tcl_Interp *interp, const char *cmd):&#160;tclAPI.c'],['../plserver_8c.html#a3c560dacc9c6efe86130a07308659ad5',1,'tcl_cmd(Tcl_Interp *interp, const char *cmd):&#160;plserver.c']]],
  ['tcl_5fgetmatrixptr',['Tcl_GetMatrixPtr',['../tclMatrix_8c.html#af3739ddb6ec61b0a5ca638948d7b55c7',1,'Tcl_GetMatrixPtr(Tcl_Interp *interp, const char *matName):&#160;tclMatrix.c'],['../tclMatrix_8h.html#ab2c44fbfdb9e0b9d4079a377c82dc126',1,'Tcl_GetMatrixPtr(Tcl_Interp *interp, const char *matName):&#160;tclMatrix.c']]],
  ['tcl_5fmatrixcmd',['Tcl_MatrixCmd',['../tclMatrix_8c.html#a03ea7ccdc423c41169df122cadc08b71',1,'Tcl_MatrixCmd(ClientData PL_UNUSED(clientData), Tcl_Interp *interp, int argc, const char **argv):&#160;tclMatrix.c'],['../tclMatrix_8h.html#abf562e3a618ffccdb8f7064fd715ad7b',1,'Tcl_MatrixCmd(ClientData clientData, Tcl_Interp *interp, int argc, const char **argv):&#160;tclMatrix.h']]],
  ['tcl_5fmatrixinstallxtnsn',['Tcl_MatrixInstallXtnsn',['../tclMatrix_8c.html#abea9f1db6809a56f0a3712da6d65eeb7',1,'Tcl_MatrixInstallXtnsn(const char *cmd, tclMatrixXtnsnProc proc):&#160;tclMatrix.c'],['../tclMatrix_8h.html#ad3fb59e9e5e16f94b1d7d0780cd768f2',1,'Tcl_MatrixInstallXtnsn(const char *cmd, tclMatrixXtnsnProc proc):&#160;tclMatrix.c']]],
  ['tcl_5ftransform',['Tcl_transform',['../tclAPI_8c.html#ac10d278b0793f65aa2d27b3ca83aed5c',1,'tclAPI.c']]],
  ['tclgetstartupscriptfilename',['TclGetStartupScriptFileName',['../tclMain_8c.html#a1c7373167ed7e868005ffffca214b24a',1,'tclMain.c']]],
  ['tcllist2py',['TclList2Py',['../namespaceTclSup.html#a9a22072a7a760eb1c275996e03c9ebda',1,'TclSup']]],
  ['tclmatrix_5ffeval',['tclMatrix_feval',['../tclAPI_8c.html#a92aef5e047b1e762bf45ec49531a072a',1,'tclAPI.c']]],
  ['tclsetstartupscriptfilename',['TclSetStartupScriptFileName',['../tclMain_8c.html#ae75c91cb39ac256237bd748315841dde',1,'tclMain.c']]],
  ['testlib_5fbroken_5fdown_5ftime',['testlib_broken_down_time',['../qsastime__testlib_8c.html#a42b776f3b8bba73a0329bafc3d382bbb',1,'qsastime_testlib.c']]],
  ['testlib_5fmjd',['testlib_MJD',['../qsastime__testlib_8c.html#a0a4b5e3359b4f06df6b7746bc9c34840',1,'qsastime_testlib.c']]],
  ['testppchar',['testppchar',['../plplot__octaveOCTAVE__wrap_8cxx.html#a920477bad4bcedede7d93be4a1d1c513',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['text',['text',['../classplstream.html#a3cdd797ab78f23697ba7a349dc0f0e74',1,'plstream::text()'],['../classplplot_1_1core_1_1PLStream.html#aadffc2af4b9889d9586f56d2fc073536',1,'plplot.core.PLStream.text()']]],
  ['text2fci',['text2fci',['../plcore_8c.html#ab5ed11ea9469ea9e4c5e1d8c5fb3e488',1,'plcore.c']]],
  ['text2num',['text2num',['../plcore_8c.html#a005b7ebf9131c9ee0266602f3830f6d5',1,'plcore.c']]],
  ['text_5fbegin_5fcairo',['text_begin_cairo',['../cairo_8c.html#aa230a846e80ae8ace11c65d3b1840eaa',1,'cairo.c']]],
  ['text_5fchar_5fcairo',['text_char_cairo',['../cairo_8c.html#aeafc2e3ee56fe62b57c15db0aa1b5a9d',1,'cairo.c']]],
  ['text_5fend_5fcairo',['text_end_cairo',['../cairo_8c.html#ab189f0a7c0f472269f925a05126f1c5d',1,'cairo.c']]],
  ['text_5fesc_5fcairo',['text_esc_cairo',['../cairo_8c.html#a324842987dca601eb1df6908fc11685a',1,'cairo.c']]],
  ['textobjectschanger',['TextObjectsChanger',['../classTextObjectsChanger.html#aa4e4697ed4075dc306be15f9273c3c85',1,'TextObjectsChanger::TextObjectsChanger(wxDC *dc, const wxFont &amp;font, const wxColour &amp;textForeground, const wxColour &amp;textBackground)'],['../classTextObjectsChanger.html#aeba76dadc5c03b48ba9182366843501e',1,'TextObjectsChanger::TextObjectsChanger(wxDC *dc, const wxFont &amp;font)']]],
  ['thindata',['thindata',['../csa_8c.html#a669921b0d6bbc7d4950d4e9782b67b87',1,'csa.c']]],
  ['timefmt',['timefmt',['../classplstream.html#a748813a8db4e3cc186b5d9fae8538c39',1,'plstream::timefmt()'],['../classplplot_1_1core_1_1PLStream.html#a691f55bf90b757df6aaca9fef7d1e20f',1,'plplot.core.PLStream.timefmt()']]],
  ['tkw_5fstorecolor',['Tkw_StoreColor',['../pltkwd_8h.html#aa590122849f626ceae0d0bf2feef9a7f',1,'pltkwd.h']]],
  ['top_5fcont_5fget',['TOP_CONT_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a76b552e9f43e5ddce941de19102d17df',1,'plplot::core::plplotjavacJNI']]],
  ['tr0',['tr0',['../namespaceplcallback.html#af87ccd94cac71f8d0469e972bcde8896',1,'plcallback']]],
  ['tr1',['tr1',['../namespaceplcallback.html#af9d7f8e297b27d5843202e24ebbbdc94',1,'plcallback']]],
  ['tr2',['tr2',['../namespaceplcallback.html#aa4de81208b179d28f8876327b7dd6c7e',1,'plcallback']]],
  ['tr2p',['tr2p',['../namespaceplcallback.html#abeb5e0d0fab7ce020df8eadfa672199f',1,'plcallback']]],
  ['tran',['tran',['../plfill_8c.html#a96d6559529e7881ab25d69ee516bd366',1,'plfill.c']]],
  ['translate_5fcolorbar_5foption',['translate_colorbar_option',['../plplot__impl_8c.html#aa09a986f70df1a7bdd15c1398c8c51c7',1,'plplot_impl.c']]],
  ['translate_5flegend_5foption',['translate_legend_option',['../plplot__impl_8c.html#a04be7b6c1cd524108031ee605cbb1de2',1,'plplot_impl.c']]],
  ['translate_5fparse_5foption',['translate_parse_option',['../plplot__impl_8c.html#aaf9fa0bd5c22c242354bea364e5018eb',1,'plplot_impl.c']]],
  ['translate_5fposition_5foption',['translate_position_option',['../plplot__impl_8c.html#a860bc00275b3a98b902d801e82315b40',1,'plplot_impl.c']]],
  ['transmitbuffer',['TransmitBuffer',['../classwxPLDevice.html#a5d478aae15542ab5fa58ef8451de3525',1,'wxPLDevice']]],
  ['triangle_5faddpoint',['triangle_addpoint',['../csa_8c.html#ad0b5597e62a4eaadfc691161ce0d5833',1,'csa.c']]],
  ['triangle_5fcalculatebc',['triangle_calculatebc',['../csa_8c.html#a69177ee7bf317363bd9b9c78656cb514',1,'csa.c']]],
  ['triangle_5fcreate',['triangle_create',['../csa_8c.html#a37b8b91050fbf95944eadd7ba22d177e',1,'csa.c']]],
  ['triangle_5fdestroy',['triangle_destroy',['../csa_8c.html#a1d77f19bb03c49d46bc43a325c9d8208',1,'csa.c']]],
  ['triangle_5fscale_5fget',['triangle_scale_get',['../nnpi_8c.html#aba9a1e6c098204686a1090f3637fb7c6',1,'nnpi.c']]]
];
